summaryrefslogtreecommitdiffstats
path: root/korn/boxcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontainer.h')
-rw-r--r--korn/boxcontainer.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/korn/boxcontainer.h b/korn/boxcontainer.h
index 800fab78..d650657e 100644
--- a/korn/boxcontainer.h
+++ b/korn/boxcontainer.h
@@ -19,7 +19,7 @@
#ifndef MK_BOXCONTAINER_H
#define MK_BOXCONTAINER_H
-#include <qobject.h>
+#include <tqobject.h>
class BoxContainerItem;
@@ -35,12 +35,12 @@ class BoxContainer : public QObject
{ Q_OBJECT
public:
/**
* Constructor: everything is passed to QObject.
*
* @param parent The parent of this object
* @param name The name of this object
*/
- BoxContainer( QObject *parent = 0, const char * name = 0 );
+ BoxContainer( TQObject *parent = 0, const char * name = 0 );
/**
* Destructor
*/
@@ -90,7 +90,7 @@ protected:
/**
* The list of BoxContainerItems.
*/
- QPtrList< BoxContainerItem > *_items;
+ TQPtrList< BoxContainerItem > *_items;
signals:
/**
@@ -35,12 +35,12 @@ class BoxContainer : public QObject
public:
/**
- * Constructor: everything is passed to QObject.
+ * Constructor: everything is passed to TQObject.
*
* @param parent The parent of this object